==> ejc-proother-impl-3.0.0-20220715.064929-134-sources.jar: com/ejianc/business/proother/contract/service/impl/SignatureServiceImpl.java <==
package com.ejianc.business.proother.contract.service.impl;

import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.ejianc.business.contractbase.filing.enums.FilingStatusEnum;
import com.ejianc.business.proother.contract.bean.ChangeEntity;
import com.ejianc.business.proother.contract.bean.ContractEntity;
import com.ejianc.business.proother.enums.PerformanceStatusEnum;
import com.ejianc.business.proother.enums.SignatureStatusEnum;
import com.ejianc.business.proother.contract.service.IChangeService;
import com.ejianc.business.proother.contract.service.IContractService;
import com.ejianc.business.proother.contract.service.ISignatureService;

import com.ejianc.foundation.file.api.IAttachmentApi;
import com.ejianc.framework.core.response.CommonResponse;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import java.util.Date;

@Service("signatureService")
public class SignatureServiceImpl implements ISignatureService {
    @Autowired
    private IContractService contractService;

    @Autowired
    private IChangeService changeService;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IAttachmentApi attachmentApi;

    @Value("${contract.mainContract}")
    private String mainContarct;

    @Value("${contract.changeContract}")
    private String changeContract;


    /**
     * 签章流程
     * 单据签章状态修改逻辑
     * 1.主合同若签章状态为已签章，则修改主合同签章状态和合同状态以及生效时间，否则只修改签章状态
     * 2.变更合同
     *      若签章状态为已签章则将变更信息回写主合同，生成变更记录，改变变更合同签章状态
     *      否则改变变更合同签章状态，修改主合同的变更合同签章状态
     * @param id
     * @param signatureStatus
     * @param
     * @return
     */
    @Override
    public CommonResponse<String> changeStatus(Long id, int signatureStatus, String refCode) {
        logger.info("进入签章状态修改流程------------->");
        if (mainContarct.equals(refCode)) {//主合同
            ContractEntity contractEntity = contractService.selectById(id);
            if (contractEntity != null) {
                if (signatureStatus == Integer.valueOf(SignatureStatusEnum.已签章.getCode())) {
                    contractEntity.setSignatureStatus(SignatureStatusEnum.已签章.getCode());
                    contractEntity.setPerformanceStatus(PerformanceStatusEnum.履约中.getCode());
                    contractEntity.setFilingStatus(FilingStatusEnum.已归档.getTypeCode());
                    contractEntity.setFilingRef(0);
                    contractEntity.setEffectiveDate(new Date());
                } else {
                    contractEntity.setSignatureStatus(String.valueOf(signatureStatus));
                }
                contractService.saveOrUpdate(contractEntity, false);
                logger.info("主合同签章状态已修改---------------->");
            } else {
                return CommonResponse.error("找不到合同，请检查合同主键！");
            }
        } else if (changeContract.equals(refCode)) {//变更合同
            ChangeEntity changeEntity = changeService.selectById(id);
            if (changeEntity != null) {
                if (signatureStatus == Integer.valueOf(SignatureStatusEnum.已签章.getCode())) {
                    return changeService.effectiveSaveWriteContract(id, changeEntity.getBillCode(), false,true);
                }else {
                    changeEntity.setSignatureStatus(String.valueOf(signatureStatus));
                    changeService.saveOrUpdate(changeEntity);
                    logger.info("变更合同签章状态已修改---------------->");
                    //回写主合同（变更合同签章状态，主合同变更状态）
                    LambdaUpdateWrapper<ContractEntity> updateWrapper = new LambdaUpdateWrapper<>();
                    updateWrapper.eq(ContractEntity::getId, changeEntity.getContractId());
                    updateWrapper.set(ContractEntity::getChangeContractSignatureStatus, Integer.valueOf(changeEntity.getSignatureStatus()));
                    contractService.update(contractService.selectById(changeEntity.getContractId()), updateWrapper, false);
                    logger.info("签章状态为已签章，回写主合同签章状态---------------->");
                }
            }else {
                return CommonResponse.error("找不到合同，请检查合同主键！");
            }
        }else {
            return CommonResponse.error("请检查refCode值是否正确！");
        }
        return CommonResponse.success("签章状态修改成功！");
    }
}

==> ejc-proother-impl-3.0.0-20221102.113840-185-sources.jar: com/ejianc/business/proother/contract/service/impl/SignatureServiceImpl.java <==
package com.ejianc.business.proother.contract.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.ejianc.business.contractbase.filing.enums.FilingStatusEnum;
import com.ejianc.business.proother.contract.bean.ChangeEntity;
import com.ejianc.business.proother.contract.bean.ContractEntity;
import com.ejianc.business.proother.contract.vo.ContractVO;
import com.ejianc.business.proother.enums.BillPushStatusEnum;
import com.ejianc.business.proother.enums.PerformanceStatusEnum;
import com.ejianc.business.proother.enums.SignatureStatusEnum;
import com.ejianc.business.proother.contract.service.IChangeService;
import com.ejianc.business.proother.contract.service.IContractService;
import com.ejianc.business.proother.contract.service.ISignatureService;

import com.ejianc.foundation.support.api.IParamConfigApi;
import com.ejianc.foundation.support.vo.ParamRegisterSetVO;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.response.CommonResponse;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import java.text.SimpleDateFormat;
import java.util.Date;

@Service("signatureService")
public class SignatureServiceImpl implements ISignatureService {
    @Autowired
    private IContractService contractService;

    @Autowired
    private IChangeService changeService;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Value("${contract.mainContract}")
    private String mainContarct;

    @Value("${contract.changeContract}")
    private String changeContract;

    @Autowired
    private IParamConfigApi paramConfigApi;

    //更新签订时间参数控制
    private final String UPDATE_CON_SIGN_DATE_PARAM_NAME = "P-U9uddl0182";

    /**
     * 签章流程
     * 单据签章状态修改逻辑
     * 1.主合同若签章状态为已签章，则修改主合同签章状态和合同状态以及生效时间，否则只修改签章状态
     * 2.变更合同
     *      若签章状态为已签章则将变更信息回写主合同，生成变更记录，改变变更合同签章状态
     *      否则改变变更合同签章状态，修改主合同的变更合同签章状态
     * @param id
     * @param signatureStatus
     * @param
     * @return
     */
    @Override
    public CommonResponse<String> changeStatus(Long id, int signatureStatus, String refCode) {
        logger.info("进入签章状态修改流程------------->");
        if (mainContarct.equals(refCode)) {//主合同
            ContractEntity contractEntity = contractService.selectById(id);
            if (contractEntity != null) {
                if (signatureStatus == Integer.valueOf(SignatureStatusEnum.已签章.getCode())) {
                    contractEntity.setSignatureStatus(SignatureStatusEnum.已签章.getCode());
                    contractEntity.setPerformanceStatus(PerformanceStatusEnum.履约中.getCode());
                    contractEntity.setFilingStatus(FilingStatusEnum.已归档.getTypeCode());
                    contractEntity.setFilingRef(0);
                    contractEntity.setEffectiveDate(new Date());

                    //查询参数判断是否需要更新合同签订日期，
                    CommonResponse<ParamRegisterSetVO> response = paramConfigApi.getByCode(UPDATE_CON_SIGN_DATE_PARAM_NAME);
                    if(!response.isSuccess()) {
                        logger.error("查询电中签章合同-【id-{}】是否更新合同签订日期参数失败，暂不更新合同签订日期: {}", id, JSONObject.toJSONString(response));
                    }
                    if(null != response.getData() && "1".equals(response.getData().getValueData())) {
                        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd");
                        //更新合同签订日期
                        logger.info("合同【id-{}，原签订日期：{}, 根据电子签章合同更新合同签订日期参数:{}，将合同签订日期改为当前签章完成日期:{}】",id,
                                sdf.format(contractEntity.getSignDate()), JSONObject.toJSONString(response.getData()), sdf.format(new Date()));
                        contractEntity.setSignDate(new Date());
                    }

                    //合同推送合同池
                    boolean pushResult = contractService.pushContract(BeanMapper.map(contractEntity, ContractVO.class));
                    if (pushResult) {
                        contractEntity.setBillPushFlag(BillPushStatusEnum.推送成功.getStatus());
                    } else {
                        contractEntity.setBillPushFlag(BillPushStatusEnum.未成功推送.getStatus());
                    }
                } else {
                    contractEntity.setSignatureStatus(String.valueOf(signatureStatus));
                }
                contractService.saveOrUpdate(contractEntity, false);
                logger.info("主合同签章状态已修改---------------->");
            } else {
                return CommonResponse.error("找不到合同，请检查合同主键！");
            }
        } else if (changeContract.equals(refCode)) {//变更合同
            ChangeEntity changeEntity = changeService.selectById(id);
            if (changeEntity != null) {
                if (signatureStatus == Integer.valueOf(SignatureStatusEnum.已签章.getCode())) {
                    return changeService.effectiveSaveWriteContract(id, changeEntity.getBillCode(), false,true);
                }else {
                    changeEntity.setSignatureStatus(String.valueOf(signatureStatus));
                    changeService.saveOrUpdate(changeEntity);
                    logger.info("变更合同签章状态已修改---------------->");
                    //回写主合同（变更合同签章状态，主合同变更状态）
                    LambdaUpdateWrapper<ContractEntity> updateWrapper = new LambdaUpdateWrapper<>();
                    updateWrapper.eq(ContractEntity::getId, changeEntity.getContractId());
                    updateWrapper.set(ContractEntity::getChangeContractSignatureStatus, Integer.valueOf(changeEntity.getSignatureStatus()));
                    contractService.update(contractService.selectById(changeEntity.getContractId()), updateWrapper, false);
                    logger.info("签章状态为已签章，回写主合同签章状态---------------->");
                }
            }else {
                return CommonResponse.error("找不到合同，请检查合同主键！");
            }
        }else {
            return CommonResponse.error("请检查refCode值是否正确！");
        }
        return CommonResponse.success("签章状态修改成功！");
    }
}
